'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pdas = require('./pdas.cjs');
var Bid = require('./Bid.cjs');
var accounts = require('./accounts.cjs');
var Operation = require('../../types/Operation.cjs');

// Operation
// -----------------

const Key = 'FindBidByAddressOperation';
const findBidByAddressOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findBidByAddressOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      address,
      auctionHouse,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const receiptAddress = pdas.findBidReceiptPda(address);
    const account = accounts.toBidReceiptAccount(await metaplex.rpc().getAccount(receiptAddress, commitment));
    scope.throwIfCanceled();

    if (account.data.tokenAccount) {
      const tokenModel = await metaplex.nfts().findTokenWithMetadataByMetadata(account.data.metadata, account.data.buyer, {
        commitment,
        loadJsonMetadata
      }).run(scope);
      return Bid.toBid(account, auctionHouse, tokenModel);
    }

    const mintModel = await metaplex.nfts().findMintWithMetadataByMetadata(account.data.metadata, {
      commitment,
      loadJsonMetadata
    }).run(scope);
    return Bid.toBid(account, auctionHouse, mintModel);
  }
};

exports.findBidByAddressOperation = findBidByAddressOperation;
exports.findBidByAddressOperationHandler = findBidByAddressOperationHandler;
//# sourceMappingURL=findBidByAddress.cjs.map
