'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var CandyMachine = require('./CandyMachine.cjs');
var accounts = require('./accounts.cjs');
var program = require('./program.cjs');
var pdas = require('./pdas.cjs');
var SdkError = require('../../errors/SdkError.cjs');
var Operation = require('../../types/Operation.cjs');
var common = require('../../utils/common.cjs');

// Operation
// -----------------

const Key = 'FindCandyMachinesByPublicKeyOperation';
const findCandyMachinesByPublicKeyFieldOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findCandyMachinesByPublicKeyFieldOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      type,
      publicKey,
      commitment
    } = operation.input;
    const accounts$1 = program.CandyMachineProgram.accounts(metaplex).mergeConfig({
      commitment
    });
    let candyMachineQuery;

    switch (type) {
      case 'authority':
        candyMachineQuery = accounts$1.candyMachineAccountsForAuthority(publicKey);
        break;

      case 'wallet':
        candyMachineQuery = accounts$1.candyMachineAccountsForWallet(publicKey);
        break;

      default:
        throw new SdkError.UnreachableCaseError(type);
    }

    const unparsedAccounts = await candyMachineQuery.get();
    scope.throwIfCanceled();
    const collectionPdas = unparsedAccounts.map(unparsedAccount => pdas.findCandyMachineCollectionPda(unparsedAccount.publicKey));
    const unparsedCollectionAccounts = await metaplex.rpc().getMultipleAccounts(collectionPdas, commitment);
    scope.throwIfCanceled();
    return common.zipMap(unparsedAccounts, unparsedCollectionAccounts, (unparsedAccount, unparsedCollectionAccount) => {
      const account = accounts.parseCandyMachineAccount(unparsedAccount);
      const collectionAccount = unparsedCollectionAccount ? accounts.parseCandyMachineCollectionAccount(unparsedCollectionAccount) : null;
      return CandyMachine.toCandyMachine(account, unparsedAccount, collectionAccount);
    });
  }
};

exports.findCandyMachinesByPublicKeyFieldOperation = findCandyMachinesByPublicKeyFieldOperation;
exports.findCandyMachinesByPublicKeyFieldOperationHandler = findCandyMachinesByPublicKeyFieldOperationHandler;
//# sourceMappingURL=findCandyMachinesByPublicKeyField.cjs.map
