'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Metadata = require('./Metadata.cjs');
var accounts = require('./accounts.cjs');
var Operation = require('../../types/Operation.cjs');
var accounts$1 = require('../tokenModule/accounts.cjs');

// -----------------
// Operation
// -----------------
const Key = 'FindMintWithMetadataByMetadataOperation';
const findMintWithMetadataByMetadataOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findMintWithMetadataByMetadataOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      address,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const metadataAccount = accounts.toMetadataAccount(await metaplex.rpc().getAccount(address, commitment));
    scope.throwIfCanceled();
    const mintAccount = accounts$1.toMintAccount(await metaplex.rpc().getAccount(metadataAccount.data.mint, commitment));
    scope.throwIfCanceled();
    let metadataModel = Metadata.toLazyMetadata(metadataAccount);

    if (loadJsonMetadata) {
      metadataModel = await metaplex.nfts().loadMetadata(metadataModel).run(scope);
    }

    return Metadata.toMintWithMetadata(mintAccount, metadataModel);
  }
};

exports.findMintWithMetadataByMetadataOperation = findMintWithMetadataByMetadataOperation;
exports.findMintWithMetadataByMetadataOperationHandler = findMintWithMetadataByMetadataOperationHandler;
//# sourceMappingURL=findMintWithMetadataByMetadata.cjs.map
