'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Metadata = require('./Metadata.cjs');
var accounts$1 = require('./accounts.cjs');
var pdas = require('./pdas.cjs');
var accounts = require('../tokenModule/accounts.cjs');
var Operation = require('../../types/Operation.cjs');
var Mint = require('../tokenModule/Mint.cjs');
var Token = require('../tokenModule/Token.cjs');

// -----------------
// Operation
// -----------------
const Key = 'FindTokenWithMetadataByAddressOperation';
const findTokenWithMetadataByAddressOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findTokenWithMetadataByAddressOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      address,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const tokenAccount = accounts.toTokenAccount(await metaplex.rpc().getAccount(address, commitment));
    const mintAddress = tokenAccount.data.mint;
    const metadataAddress = pdas.findMetadataPda(mintAddress);
    const accounts$2 = await metaplex.rpc().getMultipleAccounts([mintAddress, metadataAddress], commitment);
    scope.throwIfCanceled();
    const mintAccount = accounts.toMintAccount(accounts$2[0]);
    const metadataAccount = accounts$1.parseMetadataAccount(accounts$2[1]);
    const mintModel = Mint.toMint(mintAccount);

    if (!metadataAccount.exists) {
      return Token.toTokenWithMint(tokenAccount, mintModel);
    }

    let metadataModel = Metadata.toLazyMetadata(metadataAccount);

    if (loadJsonMetadata) {
      metadataModel = await metaplex.nfts().loadMetadata(metadataModel).run(scope);
    }

    return Metadata.toTokenWithMetadata(tokenAccount, mintModel, metadataModel);
  }
};

exports.findTokenWithMetadataByAddressOperation = findTokenWithMetadataByAddressOperation;
exports.findTokenWithMetadataByAddressOperationHandler = findTokenWithMetadataByAddressOperationHandler;
//# sourceMappingURL=findTokenWithMetadataByAddress.cjs.map
