'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Metadata = require('./Metadata.cjs');
var accounts = require('./accounts.cjs');
var Operation = require('../../types/Operation.cjs');
var pdas = require('../tokenModule/pdas.cjs');
var accounts$1 = require('../tokenModule/accounts.cjs');
var Mint = require('../tokenModule/Mint.cjs');

// -----------------
// Operation
// -----------------
const Key = 'FindTokenWithMetadataByMetadataOperation';
const findTokenWithMetadataByMetadataOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findTokenWithMetadataByMetadataOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      metadataAddress,
      ownerAddress,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const metadataAccount = accounts.toMetadataAccount(await metaplex.rpc().getAccount(metadataAddress));
    scope.throwIfCanceled();
    const mintAddress = metadataAccount.data.mint;
    const tokenAddress = pdas.findAssociatedTokenAccountPda(mintAddress, ownerAddress);
    const accounts$2 = await metaplex.rpc().getMultipleAccounts([mintAddress, tokenAddress], commitment);
    scope.throwIfCanceled();
    const mintAccount = accounts$1.toMintAccount(accounts$2[0]);
    const tokenAccount = accounts$1.toTokenAccount(accounts$2[1]);
    const mintModel = Mint.toMint(mintAccount);
    let metadataModel = Metadata.toLazyMetadata(metadataAccount);

    if (loadJsonMetadata) {
      metadataModel = await metaplex.nfts().loadMetadata(metadataModel).run(scope);
    }

    return Metadata.toTokenWithMetadata(tokenAccount, mintModel, metadataModel);
  }
};

exports.findTokenWithMetadataByMetadataOperation = findTokenWithMetadataByMetadataOperation;
exports.findTokenWithMetadataByMetadataOperationHandler = findTokenWithMetadataByMetadataOperationHandler;
//# sourceMappingURL=findTokenWithMetadataByMetadata.cjs.map
