import { toLazyMetadata, toMintWithMetadata } from './Metadata.mjs';
import { findMetadataPda } from './pdas.mjs';
import { parseMetadataAccount } from './accounts.mjs';
import { toMintAccount } from '../tokenModule/accounts.mjs';
import { useOperation } from '../../types/Operation.mjs';
import { toMint } from '../tokenModule/Mint.mjs';

// -----------------
// Operation
// -----------------
const Key = 'FindMintWithMetadataByAddressOperation';
const findMintWithMetadataByAddressOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findMintWithMetadataByAddressOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      address: mintAddress,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const metadataAddress = findMetadataPda(mintAddress);
    const accounts = await metaplex.rpc().getMultipleAccounts([mintAddress, metadataAddress], commitment);
    scope.throwIfCanceled();
    const mintAccount = toMintAccount(accounts[0]);

    if (!accounts[1].exists) {
      return toMint(mintAccount);
    }

    const metadataAccount = parseMetadataAccount(accounts[1]);
    let metadataModel = toLazyMetadata(metadataAccount);

    if (loadJsonMetadata) {
      metadataModel = await metaplex.nfts().loadMetadata(metadataModel).run(scope);
    }

    return toMintWithMetadata(mintAccount, metadataModel);
  }
};

export { findMintWithMetadataByAddressOperation, findMintWithMetadataByAddressOperationHandler };
//# sourceMappingURL=findMintWithMetadataByAddress.mjs.map
