import { findNftsByMintListOperation } from './findNftsByMintList.mjs';
import { TokenProgram } from '../tokenModule/program.mjs';
import { useOperation } from '../../types/Operation.mjs';

// -----------------
// Operation
// -----------------
const Key = 'FindNftsByOwnerOperation';
const findNftsByOwnerOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findNftsByOwnerOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      owner,
      commitment
    } = operation.input;
    const mints = await TokenProgram.tokenAccounts(metaplex).selectMint().whereOwner(owner).whereAmount(1).getDataAsPublicKeys();
    scope.throwIfCanceled();
    const nfts = await metaplex.operations().execute(findNftsByMintListOperation({
      mints,
      commitment
    }), scope);
    return nfts.filter(nft => nft !== null);
  }
};

export { findNftsByOwnerOperation, findNftsByOwnerOperationHandler };
//# sourceMappingURL=findNftsByOwner.mjs.map
