import { toLazyMetadata, toTokenWithMetadata } from './Metadata.mjs';
import { parseMetadataAccount } from './accounts.mjs';
import { findMetadataPda } from './pdas.mjs';
import { toTokenAccount, toMintAccount } from '../tokenModule/accounts.mjs';
import { useOperation } from '../../types/Operation.mjs';
import { toMint } from '../tokenModule/Mint.mjs';
import { toTokenWithMint } from '../tokenModule/Token.mjs';

// -----------------
// Operation
// -----------------
const Key = 'FindTokenWithMetadataByAddressOperation';
const findTokenWithMetadataByAddressOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findTokenWithMetadataByAddressOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      address,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const tokenAccount = toTokenAccount(await metaplex.rpc().getAccount(address, commitment));
    const mintAddress = tokenAccount.data.mint;
    const metadataAddress = findMetadataPda(mintAddress);
    const accounts = await metaplex.rpc().getMultipleAccounts([mintAddress, metadataAddress], commitment);
    scope.throwIfCanceled();
    const mintAccount = toMintAccount(accounts[0]);
    const metadataAccount = parseMetadataAccount(accounts[1]);
    const mintModel = toMint(mintAccount);

    if (!metadataAccount.exists) {
      return toTokenWithMint(tokenAccount, mintModel);
    }

    let metadataModel = toLazyMetadata(metadataAccount);

    if (loadJsonMetadata) {
      metadataModel = await metaplex.nfts().loadMetadata(metadataModel).run(scope);
    }

    return toTokenWithMetadata(tokenAccount, mintModel, metadataModel);
  }
};

export { findTokenWithMetadataByAddressOperation, findTokenWithMetadataByAddressOperationHandler };
//# sourceMappingURL=findTokenWithMetadataByAddress.mjs.map
